use std::fmt::Display;

#[derive(Debug, Default)]
pub(crate) struct I3BlocksBuilder {
    text: String,
    tooltip: String,
    class: String,
}

impl I3BlocksBuilder {
    pub(crate) fn new() -> Self {
        Self::default()
    }

    pub(crate) fn text(mut self, text: String) -> Self {
        self.text = text;
        self
    }

    pub(crate) fn tooltip(mut self, tooltip: String) -> Self {
        self.tooltip = tooltip;
        self
    }

    pub(crate) fn class(mut self, class: String) -> Self {
        self.class = class;
        self
    }

    pub(crate) fn build(self) -> I3Blocks {
        I3Blocks {
            text: self.text,
            tooltip: self.tooltip,
            class: self.class,
        }
    }
}

pub(crate) struct I3Blocks {
    text: String,
    tooltip: String,
    class: String,
}

impl I3Blocks {
    pub(crate) fn builder() -> I3BlocksBuilder {
        I3BlocksBuilder::new()
    }
}

impl Display for I3Blocks {
    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
        write!(f, "{}\n{}\n{}", self.text, self.tooltip, self.class)
    }
}
